# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_core.ipynb.

# %% auto 0
__all__ = ['say_hello', 'HelloSayer', 'foo']

# %% ../nbs/00_core.ipynb 2
def say_hello(to):
    "Say hello to somebody"
    return f'Hello {to}!'

# %% ../nbs/00_core.ipynb 4
class HelloSayer:
    "Say hello to `to` using `say_hello`"
    def __init__(self, to): self.to = to
        
    def say(self):
        "Do the saying"
        return say_hello(self.to)
#show_doc(HelloSayer.say)

# %% ../nbs/00_core.ipynb 8
def foo(): pass



# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/topocor',
                'doc_host': 'https://swalterfub.github.io',
                'git_url': 'https://github.com/swalterfub/topocor',
                'lib_path': 'topocor'},
  'syms': { 'topocor.core': { 'topocor.core.HelloSayer': ('core.html#hellosayer', 'topocor/core.py'),
                              'topocor.core.HelloSayer.__init__': ('core.html#hellosayer.__init__', 'topocor/core.py'),
                              'topocor.core.HelloSayer.say': ('core.html#hellosayer.say', 'topocor/core.py'),
                              'topocor.core.foo': ('core.html#foo', 'topocor/core.py'),
                              'topocor.core.say_hello': ('core.html#say_hello', 'topocor/core.py')}}}
